
set -e

# basic and dirty detection of the working directory
# it assumes the script is called either from initramfs-with-mca (which dracut.module/ is a subdirectory of)
# or initramfs-with-mca/installation in which case it goes to the parent directory so that dracut.module/ is available
if [ ! -d dracut.module ]; then
	cd ..
fi

PROJECT_DIR=`pwd`
SOURCE_EFI_DIR=/boot/efi/EFI/
TARGET_EFI_DIR=/EFI/
SOURCE_EFI_DIR=`realpath -m $SOURCE_EFI_DIR`
TARGET_EFI_DIR=`realpath -m $TARGET_EFI_DIR`
SOURCE_IMAGE_DIR=$SOURCE_EFI_DIR/Linux/
TARGET_IMAGE_DIR=$TARGET_EFI_DIR/Linux/
dracut_output_file=dracut-output

# This script assumes to be run by the root user (with /sbin in the path).

# Install the module
cd dracut.module
make uninstall
make install
cd -

# Generation of dracut.module/dracut.conf
cd dracut.module
sed "s|%PROJECT_DIR%|$PROJECT_DIR|g" dracut.conf.in > dracut.conf
cd -

# note: on the capri002 (as of the time those lines are wrote):
# OS disk: 250GB, /dev/nvme1n1
# /dev/nvme1n1p1	efi partition
# /dev/nvme1n1p2	root partition
# /dev/nvme1n1p3	swap partition
# Data disk: 4TB, /dev/nvme0n1 (but with a Debian installed on it...)
# /dev/nvme0n1p1	efi partition
# /dev/nvme0n1p2	root partition
# /dev/nvme0n1p3	swap partition
TARGET_DISK=/dev/nvme1n1
TARGET_EFI_PARTITION=${TARGET_DISK}p1
TARGET_ROOT_PARTITION=${TARGET_DISK}p2

# why?
e2label $TARGET_ROOT_PARTITION ROOT

# TMP: Delete bootnum 0 so that there is only one boot option for an image created by this script
efibootmgr -b 0 -B || true

# Create an initramfs image
rm -f $dracut_output_file
dracut -c ./dracut.module/dracut.conf --force |& tee -a $dracut_output_file
# the next line parses dracut output and extracts the path of the newly generated image
uefi_image_name=`grep "Creating image file" $dracut_output_file | sed -E "s|.*$SOURCE_IMAGE_DIR(.*)'.*|\1|g"`

# Why? The boot manager seems to forget the boot option if this is not done.
mkdir -p $TARGET_EFI_DIR
cp -rv $SOURCE_EFI_DIR/* $TARGET_EFI_DIR

# Set the image as a boot option
efibootmgr --create --disk $TARGET_EFI_PARTITION --label "test_deploy" --loader $TARGET_IMAGE_DIR/$uefi_image_name

echo "New initramfs image: "$TARGET_IMAGE_DIR/$uefi_image_name
